@@ -110,7 +110,7 @@ class TestConvertCommand:
         print(help_lines)
 
         # summary documentation
-        convertsummary = self.convertmodule.__doc__.split("\n", maxsplit=1)[0]
+        convertsummary = self.convertmodule.__doc__.split("\n", maxsplit=1)[0]  # ty:ignore[possibly-missing-attribute]
         # the convertsummary might be wrapped. this will probably unwrap it
         assert convertsummary in " ".join(help_lines)
 
