@@ -1,7 +1,7 @@
 from translate.lang import factory
 
 
-def test_punctranslate():
+def test_punctranslate() -> None:
     """Tests that we can translate punctuation."""
     language = factory.getlanguage("ko")
     # Nothing should be translated
@@ -14,7 +14,7 @@ def test_punctranslate():
     assert language.punctranslate("Delete file: %s?") == "Delete file: %s?"
 
 
-def test_sentences():
+def test_sentences() -> None:
     """Tests basic functionality of sentence segmentation."""
     language = factory.getlanguage("ko")
     sentences = language.sentences("")
