@@ -18,7 +18,7 @@ cpo = importorskip("translate.storage.cpo", exc_type=ImportError)
 class TestCPOUnit(test_po.TestPOUnit):
     UnitClass = cpo.pounit
 
-    def test_plurals(self):
+    def test_plurals(self) -> None:
         """Tests that plurals are handled correctly."""
         unit = self.UnitClass("Cow")
         unit.msgid_plural = ["Cows"]
@@ -42,7 +42,7 @@ class TestCPOUnit(test_po.TestPOUnit):
         assert unit.target.strings == ["Sk\u00ear", "Sk\u00eare"]
         assert unit.target == "Sk\u00ear"
 
-    def test_plural_reduction(self):
+    def test_plural_reduction(self) -> None:
         """Checks that reducing the number of plurals supplied works."""
         unit = self.UnitClass("Tree")
         unit.msgid_plural = ["Trees"]
@@ -60,7 +60,7 @@ class TestCPOUnit(test_po.TestPOUnit):
         unit.target = "Een Boom"
         assert unit.target.strings == ["Een Boom"]
 
-    def test_notes(self):
+    def test_notes(self) -> None:
         """Tests that the generic notes API works."""
         unit = self.UnitClass("File")
         assert unit.getnotes() == ""
@@ -75,7 +75,7 @@ class TestCPOUnit(test_po.TestPOUnit):
         with raises(ValueError):
             unit.getnotes("devteam")
 
-    def test_notes_withcomments(self):
+    def test_notes_withcomments(self) -> None:
         """Tests that when we add notes that look like comments that we treat them properly."""
         unit = self.UnitClass("File")
         unit.addnote("# Double commented comment")
@@ -86,7 +86,11 @@ class TestCPOUnit(test_po.TestPOUnit):
 class TestCPOFile(test_po.TestPOFile):
     StoreClass = cpo.pofile
 
-    def test_msgidcomments(self):
+    @mark.skip(reason="Native gettext doesn't handle \\r\\r\\n line endings")
+    def test_unusual_line_endings(self) -> None:
+        r"""Skip this test for CPO as native gettext doesn't support \r\r\n."""
+
+    def test_msgidcomments(self) -> None:
         """Checks that we handle msgid comments."""
         posource = 'msgid "test me"\nmsgstr ""'
         pofile = self.poparse(posource)
@@ -99,7 +103,7 @@ class TestCPOFile(test_po.TestPOFile):
         assert bytes(pofile).count(b"_:") == 1
 
     @mark.xfail(reason="Were disabled during port of Pypo to cPO - they might work")
-    def test_merge_duplicates_msgctxt(self):
+    def test_merge_duplicates_msgctxt(self) -> None:
         """Checks that merging duplicates works for msgctxt."""
         posource = '#: source1\nmsgid "test me"\nmsgstr ""\n\n#: source2\nmsgid "test me"\nmsgstr ""\n'
         pofile = self.poparse(posource)
@@ -111,7 +115,7 @@ class TestCPOFile(test_po.TestPOFile):
         assert str(pofile.units[1]).count("source2") == 2
 
     @mark.xfail(reason="Were disabled during port of Pypo to cPO - they might work")
-    def test_merge_blanks(self):
+    def test_merge_blanks(self) -> None:
         """Checks that merging adds msgid_comments to blanks."""
         posource = (
             '#: source1\nmsgid ""\nmsgstr ""\n\n#: source2\nmsgid ""\nmsgstr ""\n'
@@ -126,7 +130,7 @@ class TestCPOFile(test_po.TestPOFile):
         assert cpo.unquotefrompo(pofile.units[1].msgidcomments) == "_: source2\n"
 
     @mark.xfail(reason="Were disabled during port of Pypo to cPO - they might work")
-    def test_msgid_comment(self):
+    def test_msgid_comment(self) -> None:
         """Checks that when adding msgid_comments we place them on a newline."""
         posource = '#: source0\nmsgid "Same"\nmsgstr ""\n\n#: source1\nmsgid "Same"\nmsgstr ""\n'
         pofile = self.poparse(posource)
@@ -143,7 +147,7 @@ class TestCPOFile(test_po.TestPOFile):
             assert (str(pofile.units[i])) == expected
 
     @mark.xfail(reason="Were disabled during port of Pypo to cPO - they might work")
-    def test_keep_blanks(self):
+    def test_keep_blanks(self) -> None:
         """Checks that keeping keeps blanks and doesn't add msgid_comments."""
         posource = (
             '#: source1\nmsgid ""\nmsgstr ""\n\n#: source2\nmsgid ""\nmsgstr ""\n'
@@ -156,7 +160,7 @@ class TestCPOFile(test_po.TestPOFile):
         assert cpo.unquotefrompo(pofile.units[0].msgidcomments) == ""
         assert cpo.unquotefrompo(pofile.units[1].msgidcomments) == ""
 
-    def test_output_str_unicode(self):
+    def test_output_str_unicode(self) -> None:
         """Checks that we can serialize pofile, unit content is in unicode."""
         posource = """#: nb\nmsgid "Norwegian Bokmål"\nmsgstr ""\n"""
         pofile = self.StoreClass(BytesIO(posource.encode("UTF-8")), encoding="UTF-8")
@@ -176,7 +180,7 @@ class TestCPOFile(test_po.TestPOFile):
 
     #        assert halfstr.encode("UTF-8") in bytes(pofile)
 
-    def test_posections(self):
+    def test_posections(self) -> None:
         """Checks the content of all the expected sections of a PO message."""
         posource = '# other comment\n#. automatic comment\n#: source comment\n#, fuzzy\nmsgid "One"\nmsgstr "Een"\n'
         pofile = self.poparse(posource)
@@ -184,7 +188,7 @@ class TestCPOFile(test_po.TestPOFile):
         assert len(pofile.units) == 1
         assert bytes(pofile).decode("utf-8") == posource
 
-    def test_multiline_obsolete(self):
+    def test_multiline_obsolete(self) -> None:
         """Tests for correct output of multiline obsolete messages."""
         posource = '#~ msgid ""\n#~ "Old thing\\n"\n#~ "Second old thing"\n#~ msgstr ""\n#~ "Ou ding\\n"\n#~ "Tweede ou ding"\n'
         pofile = self.poparse(posource)
@@ -195,7 +199,7 @@ class TestCPOFile(test_po.TestPOFile):
         assert not pofile.units[0].istranslatable()
         assert bytes(pofile).decode("utf-8") == posource
 
-    def test_unassociated_comments(self):
+    def test_unassociated_comments(self) -> None:
         """Tests behaviour of unassociated comments."""
         oldsource = '# old lonesome comment\n\nmsgid "one"\nmsgstr "een"\n'
         oldfile = self.poparse(oldsource)
@@ -204,5 +208,5 @@ class TestCPOFile(test_po.TestPOFile):
         assert "# old lonesome comment\nmsgid" in bytes(oldfile).decode("utf-8")
 
     @mark.xfail(reason="removal not working in cPO")
-    def test_remove(self):
+    def test_remove(self) -> None:
         super().test_remove()
