@@ -87,10 +87,10 @@ class toml2po:
 
         Template provides the structure, source file provides translations.
         """
-        self.extraction_msg = f"extracted from {self.template_store.filename}, {self.source_store.filename}"
+        self.extraction_msg = f"extracted from {self.template_store.filename}, {self.source_store.filename}"  # ty:ignore[possibly-missing-attribute]
 
         self.source_store.makeindex()
-        for template_unit in self.template_store.units:
+        for template_unit in self.template_store.units:  # ty:ignore[possibly-missing-attribute]
             target_unit = self.convert_unit(template_unit)
 
             for location in target_unit.getlocations():
