@@ -16,13 +16,13 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 
-"""Module to guess the language ISO code based on the 'Language-Team' entry in
+"""
+Module to guess the language ISO code based on the 'Language-Team' entry in
 the header of a Gettext PO file.
 """
 
 import re
 
-
 __all__ = ("LANG_TEAM_CONTACT_SNIPPETS", "guess_language")
 
 LANG_TEAM_REGEX = (
@@ -36,7 +36,7 @@ LANG_TEAM_REGEX = (
     ("fedoraproject", "trans-([a-z_A-Z]+)@lists.fedoraproject.org", None),
     ("gnome.org", "gnome-([a-z_A-Z]+)-list@gnome.org", ["latin"]),
 )
-"""Data for regular expression based extraction.  The fieds are: prefilter
+"""Data for regular expression based extraction. The fields are: prefilter
 information, regex with single group that contains the language code,
 postfilter."""
 
@@ -518,7 +518,7 @@ LANG_TEAM_LANGUAGE_SNIPPETS = {
         "Finnish",
         "Suomi",
     ),
-    "fo": ("Faroese",),
+    "fo": ("Faroese",),  # codespell:ignore
     "fr": (
         "French",
         "Français",
@@ -691,18 +691,19 @@ LANG_TEAM_LANGUAGE_SNIPPETS = {
     ),
 }
 """Language codes with snippets of language names, including English, native
-spelling and varients, that can be used to uniquely identify the language"""
+spelling and variants, that can be used to uniquely identify the language"""
 
 
 def _regex_guesser(prefilter, regex, string, postfilter=None):
-    """Use regular expressions to extract the language team
+    """
+    Use regular expressions to extract the language team.
 
     :param prefilter: simple filter to apply before attempting the regex
     :param regex: regular expression with one group that will contain
     the language code
     :param string: the language team string that should be examined
     :param postfilter: filter to apply to reject any potential matches
-    after they have been retreived by the regex
+    after they have been retrieved by the regex
     :return: ISO language code for the found language
     """
     # TODO instead of a posfilter, have a dictionary of transform rules
@@ -724,17 +725,18 @@ def _regex_guesser(prefilter, regex, string, postfilter=None):
 
 
 def _nofilter(text):
-    """Return the supplied text unchanged"""
+    """Return the supplied text unchanged."""
     return text
 
 
 def _lower(text):
-    """Convert the supplied text to lowercase"""
+    """Convert the supplied text to lowercase."""
     return text.lower()
 
 
 def _snippet_guesser(snippets_dict, string, filter_=_nofilter):
-    """Guess the language based on a snippet of text in the language team
+    """
+    Guess the language based on a snippet of text in the language team
     string.
 
     :param snippets_dict: A dict of snippets that can be used to identify a
@@ -752,8 +754,7 @@ def _snippet_guesser(snippets_dict, string, filter_=_nofilter):
 
 
 def guess_language(team_string):
-    """Gueses the language of a PO file based on the Language-Team entry"""
-
+    """Gueses the language of a PO file based on the Language-Team entry."""
     for prefilter, regex, postfilter in LANG_TEAM_REGEX:
         lang = _regex_guesser(prefilter, regex, team_string, postfilter)
         if lang:
@@ -780,4 +781,4 @@ if __name__ == "__main__":
 
     for fname in argv[1:]:
         store = factory.getobject(fname)
-        print(fname, guess_language(store.parseheader().get("Language-Team", "")))
+        print(fname, guess_language(store.parseheader().get("Language-Team", "")))  # noqa: T201  # ty:ignore[unresolved-attribute]
