@@ -79,6 +79,7 @@ from typing import (
     Any,
     BinaryIO,
     ClassVar,
+    NotRequired,
     TextIO,
     TypedDict,
     cast,
@@ -128,7 +129,7 @@ class BaseJsonUnit(base.DictUnit):
     def setid(self, value, unitid=None) -> None:
         super().setid(value, unitid)
         self.get_unitid()
-        self._item = self._unitid.parts[-1][1]
+        self._item = self._unitid.parts[-1][1]  # ty:ignore[possibly-missing-attribute]
 
     def getid(self):
         return self._id
@@ -166,12 +167,13 @@ class FlatJsonUnit(BaseJsonUnit):
 
 
 class DumpArgsType(TypedDict):
-    separators: tuple[str, ...]
+    separators: tuple[str, str]
     indent: int
     ensure_ascii: bool
+    sort_keys: NotRequired[bool]
 
 
-class JsonFile(base.DictStore):
+class JsonFile(base.DictStore[BaseJsonUnit]):
     """A JSON file."""
 
     UnitClass: ClassVar[type[BaseJsonUnit]] = FlatJsonUnit
@@ -387,9 +389,10 @@ class I18NextUnit(JsonNestedUnit):
         if not isinstance(self.target, multistring):
             super().storevalues(output)
         else:
-            if len(self.target.strings) > len(self._store.get_plural_tags()):
+            if len(self.target.strings) > len(self._store.get_plural_tags()):  # ty:ignore[possibly-missing-attribute]
                 self.target.extra_strings = self.target.extra_strings[
-                    : len(self._store.get_plural_tags()) - 1
+                    : len(self._store.get_plural_tags())  # ty:ignore[possibly-missing-attribute]
+                    - 1
                 ]
             self._fixup_item()
             for i, value in enumerate(self.target.strings):
@@ -477,7 +480,7 @@ class I18NextV4Unit(I18NextUnit):
 
     def _get_plural_labels(self, count):
         base_name = self._get_base_name()
-        return [f"{base_name}_{self._store.get_plural_tags()[i]}" for i in range(count)]
+        return [f"{base_name}_{self._store.get_plural_tags()[i]}" for i in range(count)]  # ty:ignore[possibly-missing-attribute]
 
 
 class I18NextV4File(JsonNestedFile):
@@ -600,7 +603,7 @@ class GoTextJsonUnit(BaseJsonUnit):
     def getvalue(self):
         target = self.target
         if isinstance(target, multistring):
-            strings = self.sync_plural_count(target, self._store.get_plural_tags())
+            strings = self.sync_plural_count(target, self._store.get_plural_tags())  # ty:ignore[possibly-missing-attribute]
             target = {
                 "select": {
                     "feature": "plural",
@@ -610,7 +613,7 @@ class GoTextJsonUnit(BaseJsonUnit):
                 target["select"]["arg"] = self.placeholders[0]["id"]
             target["select"]["cases"] = {
                 plural: {"msg": strings[offset]}
-                for offset, plural in enumerate(self._store.get_plural_tags())
+                for offset, plural in enumerate(self._store.get_plural_tags())  # ty:ignore[possibly-missing-attribute]
             }
         value = {"id": self._unitid.parts if self._unitid else self.getid()}
         if self.message:
@@ -712,10 +715,10 @@ class GoI18NJsonUnit(FlatJsonUnit):
     def getvalue(self):
         target = self.target
         if isinstance(target, multistring):
-            strings = self.sync_plural_count(target, self._store.get_plural_tags())
+            strings = self.sync_plural_count(target, self._store.get_plural_tags())  # ty:ignore[possibly-missing-attribute]
             target = {
                 plural: strings[offset]
-                for offset, plural in enumerate(self._store.get_plural_tags())
+                for offset, plural in enumerate(self._store.get_plural_tags())  # ty:ignore[possibly-missing-attribute]
             }
         value = {"id": self.getid()}
         if self.notes:
@@ -794,8 +797,8 @@ class GoI18NV2JsonUnit(FlatJsonUnit):
         if self.notes:
             target["description"] = self.notes
 
-        strings = self.sync_plural_count(self.target, self._store.get_plural_tags())
-        for offset, plural in enumerate(self._store.get_plural_tags()):
+        strings = self.sync_plural_count(self.target, self._store.get_plural_tags())  # ty:ignore[possibly-missing-attribute]
+        for offset, plural in enumerate(self._store.get_plural_tags()):  # ty:ignore[possibly-missing-attribute]
             target[plural] = strings[offset]
 
         return target
@@ -878,7 +881,8 @@ class ARBJsonUnit(base.MetadataTranslationUnit, FlatJsonUnit):
                 self.storevalue(output, value, override_key=key)
         else:
             self.storevalue(output, self.target, override_key=identifier)
-            self.storevalue(output, self.metadata, override_key=f"@{identifier}")
+            if self.metadata:
+                self.storevalue(output, self.metadata, override_key=f"@{identifier}")
 
     def isheader(self):
         return self._id == "@"
