@@ -416,7 +416,7 @@ class phpfile(base.TranslationStore):
             newunit.addnote(comment, "developer")
         self.addunit(newunit)
 
-    def parse(self, phpsrc) -> None:
+    def parse(self, phpsrc) -> None:  # ty:ignore[invalid-method-override]
         """Read the source of a PHP file in and include them as units."""
 
         def handle_array(prefix, nodes, lexer) -> None:
