@@ -88,14 +88,14 @@ class Xliff1Unit(XliffUnit):
         S_SIGNED_OFF: (state.FINAL, state.MAX),
     }
 
-    def __init__(self, source, empty=False, **kwargs):
+    def __init__(self, source, empty=False, **kwargs) -> None:
         """Override the constructor to set xml:space="preserve"."""
         super().__init__(source, empty, **kwargs)
         if empty:
             return
         setXMLspace(self.xmlelement, "preserve")
 
-    def createlanguageNode(self, lang, text, purpose):
+    def createlanguageNode(self, lang, text, purpose):  # ty:ignore[invalid-method-override]
         """Returns an xml Element setup with given parameters."""
         # TODO: for now we do source, but we have to test if it is target,
         # perhaps with parameter. Alternatively, we can use lang, if
@@ -111,12 +111,15 @@ class Xliff1Unit(XliffUnit):
         return langset
 
     def addalttrans(
-        self, txt, origin=None, lang=None, sourcetxt=None, matchquality=None
-    ):
+        self,
+        txt: str,
+        origin: str | None = None,
+        lang: str | None = None,
+        sourcetxt: str | None = None,
+        matchquality: str | None = None,
+    ) -> None:
         """
         Adds an alt-trans tag and alt-trans components to the unit.
-
-        :type txt: String
         :param txt: Alternative translation of the source text.
         """
         # TODO: support adding a source tag ad match quality attribute.  At the
@@ -161,16 +164,16 @@ class Xliff1Unit(XliffUnit):
                 )
                 # TODO: support multiple targets better
                 # TODO: support notes in alt-trans
-                newunit.xmlelement = node
+                newunit.xmlelement = node  # ty:ignore[unresolved-attribute]
 
                 translist.append(newunit)
         return translist
 
-    def delalttrans(self, alternative):
+    def delalttrans(self, alternative) -> None:
         """Removes the supplied alternative from the list of alt-trans tags."""
         self.xmlelement.remove(alternative.xmlelement)
 
-    def addnote(self, text, origin=None, position="append"):
+    def addnote(self, text, origin=None, position="append") -> None:
         """Add a note specifically in a "note" tag."""
         if position != "append":
             self.removenotes(origin=origin)
@@ -184,14 +187,12 @@ class Xliff1Unit(XliffUnit):
         if origin:
             note.set("from", origin)
 
-    def _getnotelist(self, origin=None):
+    def _getnotelist(self, origin=None) -> list[str]:
         """
         Returns the text from notes matching ``origin`` or all notes.
 
         :param origin: The origin of the note (or note type)
-        :type origin: String
         :return: The text from notes matching ``origin``
-        :rtype: List
         """
         note_nodes = self.xmlelement.iterdescendants(self.namespaced("note"))
         # TODO: consider using xpath to construct initial_list directly
@@ -214,14 +215,14 @@ class Xliff1Unit(XliffUnit):
     def getnotes(self, origin=None):
         return "\n".join(self._getnotelist(origin=origin))
 
-    def removenotes(self, origin=None):
+    def removenotes(self, origin=None) -> None:
         """Remove all the translator notes."""
         notes = self.xmlelement.iterdescendants(self.namespaced("note"))
         for note in notes:
             if self.correctorigin(note, origin=origin):
                 self.xmlelement.remove(note)
 
-    def adderror(self, errorname, errortext):
+    def adderror(self, errorname, errortext) -> None:
         """Adds an error message to this unit."""
         # TODO: consider factoring out: some duplication between XLIFF and TMX
         text = errorname
@@ -260,7 +261,7 @@ class Xliff1Unit(XliffUnit):
 
         return state_n
 
-    def set_state_n(self, value):
+    def set_state_n(self, value) -> None:
         if value not in self.statemap_r:
             value = self.get_state_id(value)
 
@@ -280,7 +281,7 @@ class Xliff1Unit(XliffUnit):
         """States whether this unit is approved."""
         return self.xmlelement.get("approved") == "yes"
 
-    def markapproved(self, value=True):
+    def markapproved(self, value=True) -> None:
         """Mark this unit as approved."""
         if value:
             self.xmlelement.set("approved", "yes")
@@ -291,7 +292,7 @@ class Xliff1Unit(XliffUnit):
         """States whether this unit needs to be reviewed."""
         return self.get_state_id() == self.S_NEEDS_REVIEW
 
-    def markreviewneeded(self, needsreview=True, explanation=None):
+    def markreviewneeded(self, needsreview=True, explanation=None) -> None:
         """
         Marks the unit to indicate whether it needs review.
 
@@ -312,7 +313,7 @@ class Xliff1Unit(XliffUnit):
         #         targetnode.get("state") == "needs-review-translation")
         return not self.isapproved() and bool(self.target)
 
-    def markfuzzy(self, value=True):
+    def markfuzzy(self, value=True) -> None:
         state_id = self.get_state_id()
         if value:
             self.markapproved(False)
@@ -323,7 +324,7 @@ class Xliff1Unit(XliffUnit):
             if state_id < self.S_UNREVIEWED:
                 self.set_state_n(self.S_UNREVIEWED)
 
-    def settarget(self, target, lang="xx", append=False):
+    def settarget(self, target, lang="xx", append=False) -> None:
         """Sets the target string to the given value."""
         super().settarget(target, lang, append)
         if target:
@@ -341,12 +342,19 @@ class Xliff1Unit(XliffUnit):
         value = self.xmlelement.get("translate")
         return not value or value.lower() != "no"
 
-    def marktranslated(self):
+    def marktranslatable(self, value=True) -> None:
+        """Mark this unit as translatable or untranslatable."""
+        if value:
+            self.xmlelement.set("translate", "yes")
+        elif self.istranslatable():
+            self.xmlelement.set("translate", "no")
+
+    def marktranslated(self) -> None:
         state_id = self.get_state_id()
         if state_id < self.S_UNREVIEWED:
             self.set_state_n(self.S_UNREVIEWED)
 
-    def setid(self, id):
+    def setid(self, id) -> None:  # ty:ignore[invalid-method-override]
         # sanitize id in case ID_SEPARATOR is present
         self.xmlelement.set("id", id.replace(ID_SEPARATOR, ID_SEPARATOR_SAFE))
 
@@ -367,7 +375,7 @@ class Xliff1Unit(XliffUnit):
         )
         return uid
 
-    def addlocation(self, location):
+    def addlocation(self, location) -> None:
         if ":" in location:
             sourcefile, linenumber = location.rsplit(":", 1)
             contexts = [("sourcefile", sourcefile), ("linenumber", linenumber)]
@@ -388,7 +396,7 @@ class Xliff1Unit(XliffUnit):
 
         return locations
 
-    def createcontextgroup(self, name, contexts=None, purpose=None):
+    def createcontextgroup(self, name, contexts=None, purpose=None) -> None:
         """
         Add the context group to the trans-unit with contexts a list with
         (type, text) tuples describing each context.
@@ -465,7 +473,7 @@ class Xliff1Unit(XliffUnit):
         )
 
 
-class Xliff1File(XliffFile):
+class Xliff1File(XliffFile[Xliff1Unit]):
     """Class representing a XLIFF file store."""
 
     UnitClass = Xliff1Unit
@@ -494,7 +502,7 @@ class Xliff1File(XliffFile):
     suggestions_in_format = True
     """xliff units have alttrans tags which can be used to store suggestions"""
 
-    def initbody(self):
+    def initbody(self) -> None:
         # detect the xliff namespace, handle both 1.1 and 1.2
         for ns in self.document.getroot().nsmap.values():
             if ns and ns.startswith(self.unversioned_namespace):
@@ -553,7 +561,7 @@ class Xliff1File(XliffFile):
         """Set the name of the given file."""
         return filenode.set("original", filename)
 
-    def setsourcelanguage(self, language):
+    def setsourcelanguage(self, language) -> None:  # ty:ignore[invalid-method-override]
         if not language:
             return
         for filenode in self.document.getroot().iterchildren(self.namespaced("file")):
@@ -565,7 +573,7 @@ class Xliff1File(XliffFile):
 
     sourcelanguage = property(getsourcelanguage, setsourcelanguage)
 
-    def settargetlanguage(self, language):
+    def settargetlanguage(self, language) -> None:  # ty:ignore[invalid-method-override]
         if not language:
             return
         for filenode in self.document.getroot().iterchildren(self.namespaced("file")):
@@ -592,7 +600,7 @@ class Xliff1File(XliffFile):
                 return self.getdatatype(filenames[0])
         return ""
 
-    def getdate(self, filename=None):
+    def getdate(self, filename=None) -> str | None:
         """
         Returns the date attribute for the file.
 
@@ -600,7 +608,6 @@ class Xliff1File(XliffFile):
         If the date attribute is not specified, None is returned.
 
         :returns: Date attribute of file
-        :rtype: Date or None
         """
         if filename:
             node = self.getfilenode(filename)
@@ -612,7 +619,7 @@ class Xliff1File(XliffFile):
                 return self.getdate(filenames[0])
         return None
 
-    def removedefaultfile(self):
+    def removedefaultfile(self) -> None:
         """
         We want to remove the default file-tag as soon as possible if we
         know if still present and empty.
@@ -649,7 +656,7 @@ class Xliff1File(XliffFile):
             return None
         return etree.SubElement(filenode, self.namespaced("body"))
 
-    def addunit(self, unit, new=True):
+    def addunit(self, unit, new=True) -> None:
         parts = unit.getid().split("\x04")
         if len(parts) > 1:
             filename, unitid = parts[0], "\x04".join(parts[1:])
@@ -679,7 +686,7 @@ class Xliff1File(XliffFile):
                 target_group.append(unit.xmlelement)
             else:
                 # Add directly to body
-                self.body.append(unit.xmlelement)
+                self.body.append(unit.xmlelement)  # ty:ignore[possibly-missing-attribute]
 
     def addsourceunit(self, source, filename="NoName", createifmissing=False):
         """
@@ -697,12 +704,11 @@ class Xliff1File(XliffFile):
         unit.setid(f"{messagenum}")
         return unit
 
-    def switchfile(self, filename, createifmissing=False):
+    def switchfile(self, filename: str, createifmissing: bool = False) -> bool:
         """
         Adds the given trans-unit (will create the nodes required if asked).
 
         :returns: Success
-        :rtype: Boolean
         """
         if self._filename == filename:
             return True
@@ -721,7 +727,7 @@ class Xliff1File(XliffFile):
         """Adds a group tag into the specified file."""
         if not self.switchfile(filename, createifmissing):
             return None
-        group = etree.SubElement(self.body, self.namespaced("group"))
+        group = etree.SubElement(self.body, self.namespaced("group"))  # ty:ignore[no-matching-overload]
         if restype:
             group.set("restype", restype)
         return group
@@ -734,18 +740,18 @@ class Xliff1File(XliffFile):
         :returns: The matching or newly created group element
         """
         # Try to find a matching group in the current body
-        for group in self.body.iterchildren(self.namespaced("group")):
+        for group in self.body.iterchildren(self.namespaced("group")):  # ty:ignore[possibly-missing-attribute]
             # Check if all attributes match
             if group.attrib == source_group.attrib:
                 return group
 
         # No matching group found, create a new one
-        group = etree.SubElement(self.body, self.namespaced("group"))
+        group = etree.SubElement(self.body, self.namespaced("group"))  # ty:ignore[no-matching-overload]
         for attr, value in source_group.attrib.items():
             group.set(attr, value)
         return group
 
-    def serialize(self, out):
+    def serialize(self, out) -> None:
         self.removedefaultfile()
         super().serialize(out)
 
