@@ -31,7 +31,9 @@ class Translatable:
     which correspond to placeables.
     """
 
-    def __init__(self, placeable_name, xpath, dom_node, source, is_inline=False):
+    def __init__(
+        self, placeable_name, xpath, dom_node, source, is_inline=False
+    ) -> None:
         self.placeable_name = placeable_name
         self.source = source
         self.xpath = xpath
@@ -68,7 +70,9 @@ class ParseState:
     (via the function apply).
     """
 
-    def __init__(self, no_translate_content_elements, inline_elements={}, nsmap={}):
+    def __init__(
+        self, no_translate_content_elements, inline_elements={}, nsmap={}
+    ) -> None:
         self.no_translate_content_elements = no_translate_content_elements
         self.inline_elements = inline_elements
         self.is_inline = False
@@ -239,7 +243,7 @@ def _process_children(dom_node, state, process_func):
     return children
 
 
-def compact_tag(nsmap, namespace, tag):
+def compact_tag(nsmap, namespace, tag) -> str:
     if namespace in nsmap:
         return f"{nsmap[namespace]}:{tag}"
     return f"{{{namespace}}}{tag}"
@@ -286,7 +290,7 @@ def find_translatable_dom_nodes(dom_node, state, process_func=process_translatab
 
 
 class IdMaker:
-    def __init__(self):
+    def __init__(self) -> None:
         self._max_id = 0
         self._obj_id_map = {}
 
@@ -327,7 +331,7 @@ def _make_store_adder(store):
     """
     id_maker = IdMaker()
 
-    def add_translatable_to_store(parent_translatable, translatable):
+    def add_translatable_to_store(parent_translatable, translatable) -> None:
         """
         Construct a new translation unit, set its source and location
         information and add it to 'store'.
@@ -352,7 +356,7 @@ def make_postore_adder(store, id_maker, filename):
     to 'placeable_quoter'.
     """
 
-    def add_translatable_to_store(parent_translatable, translatable):
+    def add_translatable_to_store(parent_translatable, translatable) -> None:
         """
         Construct a new translation unit, set its source and location
         information and add it to 'store'.
@@ -376,7 +380,9 @@ def make_postore_adder(store, id_maker, filename):
     return add_translatable_to_store
 
 
-def _walk_idml_translatable_tree(translatables, store_adder, parent_translatable):
+def _walk_idml_translatable_tree(
+    translatables, store_adder, parent_translatable
+) -> None:
     """
     Traverse all the found IDML translatables and add them to the Store.
 
@@ -395,7 +401,7 @@ def _walk_idml_translatable_tree(translatables, store_adder, parent_translatable
 
 def _walk_translatable_tree(
     translatables, store_adder, parent_translatable, stored_by_parent=False
-):
+) -> None:
     """
     Traverse all the found translatables and add them to the Store.
 
